<?php
/**
 * tattoo-expert: Customizer
 *
 * @package WordPress
 * @subpackage tattoo-expert
 * @since 1.0
 */

function tattoo_expert_customize_register( $wp_customize ) {

	$wp_customize->add_panel( 'tattoo_expert_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'Theme Settings', 'tattoo-expert' ),
	    'description' => __( 'Description of what this panel does.', 'tattoo-expert' ),
	) );

	$wp_customize->add_section( 'tattoo_expert_theme_options_section', array(
    	'title'      => __( 'General Settings', 'tattoo-expert' ),
		'priority'   => 30,
		'panel' => 'tattoo_expert_panel_id'
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('tattoo_expert_theme_options',array(
        'default' => __('Right Sidebar','tattoo-expert'),
        'sanitize_callback' => 'tattoo_expert_sanitize_choices'	        
	));

	$wp_customize->add_control('tattoo_expert_theme_options',array(
        'type' => 'radio',
        'label' => __('Do you want this section','tattoo-expert'),
        'section' => 'tattoo_expert_theme_options_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','tattoo-expert'),
            'Right Sidebar' => __('Right Sidebar','tattoo-expert'),
            'One Column' => __('One Column','tattoo-expert'),
            'Three Columns' => __('Three Columns','tattoo-expert'),
            'Four Columns' => __('Four Columns','tattoo-expert'),
            'Grid Layout' => __('Grid Layout','tattoo-expert')
        ),
	));

	// Top Bar
	$wp_customize->add_section( 'tattoo_expert_contact_details', array(
    	'title'      => __( 'Top Bar', 'tattoo-expert' ),
		'priority'   => null,
		'panel' => 'tattoo_expert_panel_id'
	) );

	$wp_customize->add_setting('tattoo_expert_call1',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('tattoo_expert_call1',array(
		'label'	=> __('Phone Number','tattoo-expert'),
		'section'=> 'tattoo_expert_contact_details',
		'setting'=> 'tattoo_expert_call1',
		'type'=> 'text'
	));

	$wp_customize->add_setting('tattoo_expert_email1',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('tattoo_expert_email1',array(
		'label'	=> __('Email Us','tattoo-expert'),
		'section'=> 'tattoo_expert_contact_details',
		'setting'=> 'tattoo_expert_email1',
		'type'=> 'text'
	));

	//social icons
	$wp_customize->add_section( 'tattoo_expert_social', array(
    	'title'      => __( 'Social Icons', 'tattoo-expert' ),
		'priority'   => null,
		'panel' => 'tattoo_expert_panel_id'
	) );

	$wp_customize->add_setting('tattoo_expert_facebook_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('tattoo_expert_facebook_url',array(
		'label'	=> __('Add Facebook link','tattoo-expert'),
		'section'	=> 'tattoo_expert_social',
		'setting'	=> 'tattoo_expert_facebook_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('tattoo_expert_twitter_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('tattoo_expert_twitter_url',array(
		'label'	=> __('Add Twitter link','tattoo-expert'),
		'section'	=> 'tattoo_expert_social',
		'setting'	=> 'tattoo_expert_twitter_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('tattoo_expert_insta_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('tattoo_expert_insta_url',array(
		'label'	=> __('Add Instagram link','tattoo-expert'),
		'section'	=> 'tattoo_expert_social',
		'setting'	=> 'tattoo_expert_insta_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('tattoo_expert_linkedin_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('tattoo_expert_linkedin_url',array(
		'label'	=> __('Add Linkedin link','tattoo-expert'),
		'section'	=> 'tattoo_expert_social',
		'setting'	=> 'tattoo_expert_linkedin_url',
		'type'	=> 'url'
	));

	$wp_customize->add_setting('tattoo_expert_pinterest_url',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));	
	$wp_customize->add_control('tattoo_expert_pinterest_url',array(
		'label'	=> __('Add Pintrest link','tattoo-expert'),
		'section'	=> 'tattoo_expert_social',
		'setting'	=> 'tattoo_expert_pinterest_url',
		'type'	=> 'url'
	));

	//home page slider
	$wp_customize->add_section( 'tattoo_expert_slider_section' , array(
    	'title'      => __( 'Slider Settings', 'tattoo-expert' ),
		'priority'   => null,
		'panel' => 'tattoo_expert_panel_id'
	) );

	$wp_customize->add_setting('tattoo_expert_slider_hide_show',array(
       	'default' => 'true',
       	'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('tattoo_expert_slider_hide_show',array(
	   	'type' => 'checkbox',
	   	'label' => __('Show / Hide slider','tattoo-expert'),
	   	'description' => __('Image Size ( 1600px x 582px )','tattoo-expert'),
	   	'section' => 'tattoo_expert_slider_section',
	));

	for ( $count = 1; $count <= 4; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'tattoo_expert_slider' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'tattoo_expert_sanitize_dropdown_pages'
		) );

		$wp_customize->add_control( 'tattoo_expert_slider' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'tattoo-expert' ),
			'section'  => 'tattoo_expert_slider_section',
			'type'     => 'dropdown-pages'
		) );
	}

	//	OUR SERVICES
	$wp_customize->add_section('tattoo_expert_service',array(
		'title'	=> __('Our Services','tattoo-expert'),
		'description'=> __('This section will appear below the slider.','tattoo-expert'),
		'panel' => 'tattoo_expert_panel_id',
	));
	
	$wp_customize->add_setting('tattoo_expert_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('tattoo_expert_title',array(
		'label'	=> __('Section Title','tattoo-expert'),
		'section'	=> 'tattoo_expert_service',
		'setting'	=> 'tattoo_expert_title',
		'type'		=> 'text'
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('tattoo_expert_cat',array(
		'default'	=> 'select',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('tattoo_expert_cat',array(
		'type'    => 'select',
		'choices' => $cat_pst,
		'label' => __('Select Category to display Post','tattoo-expert'),
		'section' => 'tattoo_expert_service',
	));

	//Footer
    $wp_customize->add_section( 'tattoo_expert_footer', array(
    	'title'      => __( 'Footer Text', 'tattoo-expert' ),
		'priority'   => null,
		'panel' => 'tattoo_expert_panel_id'
	) );

    $wp_customize->add_setting('tattoo_expert_footer_copy',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('tattoo_expert_footer_copy',array(
		'label'	=> __('Footer Text','tattoo-expert'),
		'section'	=> 'tattoo_expert_footer',
		'setting'	=> 'tattoo_expert_footer_copy',
		'type'		=> 'text'
	));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'tattoo_expert_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'tattoo_expert_customize_partial_blogdescription',
	) );

	//front page
	$num_sections = apply_filters( 'tattoo_expert_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		$wp_customize->add_setting( 'panel_' . $i, array(
			'default'           => false,
			'sanitize_callback' => 'tattoo_expert_sanitize_dropdown_pages',
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'panel_' . $i, array(
			/* translators: %d is the front page section number */
			'label'          => sprintf( __( 'Front Page Section %d Content', 'tattoo-expert' ), $i ),
			'description'    => ( 1 !== $i ? '' : __( 'Select pages to feature in each area from the dropdowns. Add an image to a section by setting a featured image in the page editor. Empty sections will not be displayed.', 'tattoo-expert' ) ),
			'section'        => 'theme_options',
			'type'           => 'dropdown-pages',
			'allow_addition' => true,
			'active_callback' => 'tattoo_expert_is_static_front_page',
		) );

		$wp_customize->selective_refresh->add_partial( 'panel_' . $i, array(
			'selector'            => '#panel' . $i,
			'render_callback'     => 'tattoo_expert_front_page_section',
			'container_inclusive' => true,
		) );
	}
}
add_action( 'customize_register', 'tattoo_expert_customize_register' );

function tattoo_expert_customize_partial_blogname() {
	bloginfo( 'name' );
}

function tattoo_expert_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

function tattoo_expert_is_static_front_page() {
	return ( is_front_page() && ! is_home() );
}

function tattoo_expert_is_view_with_layout_option() {
	// This option is available on all pages. It's also available on archives when there isn't a sidebar.
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
}

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Tattoo_Expert_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Tattoo_Expert_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new Tattoo_Expert_Customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'priority' => 9,
					'title'    => esc_html__( 'Tattoo Expert Pro ', 'tattoo-expert' ),
					'pro_text' => esc_html__( 'Go Pro','tattoo-expert' ),
					'pro_url'  => esc_url( 'https://www.luzuk.com/themes/wordpress-tattoo-theme/' ),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'tattoo-expert-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'tattoo-expert-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Tattoo_Expert_Customize::get_instance();